@@ -1288,6 +1288,7 @@ class Playlist(ViewContainer):
     @log
     def populate(self):
         if grilo.tracker:
+            self.playlists_model.clear()
             GLib.idle_add(grilo.populate_playlists, self._offset,
                           self._add_playlist_item)
 
@@ -1459,7 +1460,7 @@ class Search(ViewContainer):
 
         key = '%s-%s' % (artist, album)
         if key not in self._albums:
-            self._albums[key] = Grl.MediaBox()
+            self._albums[key] = Grl.Media()
             self._albums[key].set_title(album)
             self._albums[key].add_author(artist)
             self._albums[key].set_source(source.get_id())
