@@ -204,7 +204,7 @@ class Window(Gtk.ApplicationWindow):
         cursor = None
 
         Query()
-        if Query.music_folder and Query.download_folder:
+        if Query.music_folder:
             try:
                 cursor = tracker.query(Query.all_songs_count(), None)
                 if cursor is not None and cursor.next(None):
@@ -320,6 +320,11 @@ class Window(Gtk.ApplicationWindow):
         self.toolbar._selection_menu_label.set_text(_("Click on items to select them"))
         self._stack.get_visible_child().queue_draw()
 
+    def _show_notification(self):
+        self.notification_handler = None
+        self.notification.show_all()
+        return False
+
     @log
     def _init_loading_notification(self):
         self.notification = Gd.Notification()
@@ -336,7 +341,7 @@ class Window(Gtk.ApplicationWindow):
         if self.notification_handler:
             GLib.Source.remove(self.notification_handler)
             self.notification_handler = None
-        self.notification_handler = GLib.timeout_add(1000, self.notification.show_all)
+        self.notification_handler = GLib.timeout_add(1000, self._show_notification)
 
     @log
     def _init_playlist_removal_notification(self):
@@ -425,7 +430,7 @@ class Window(Gtk.ApplicationWindow):
         self.curr_view = stack.get_visible_child()
 
         # Switch to all albums view when we're clicking Albums
-        if self.curr_view == self.views[0]:
+        if self.curr_view == self.views[0] and not (self.prev_view == self.views[4] or self.prev_view == self.views[5]):
             self.curr_view.set_visible_child(self.curr_view._grid)
 
         # Slide out sidebar on switching to Artists or Playlists view
@@ -451,10 +456,14 @@ class Window(Gtk.ApplicationWindow):
         self.toolbar.searchbar.show_bar(button.get_active(),
                                         self.curr_view != self.views[4])
         if (not button.get_active() and
-                (self.curr_view == self.views[4] or self.curr_view == self.views[5]) and
-                self.toolbar._state == ToolbarState.MAIN):
-            # We should get back to the view before the search
-            self._stack.set_visible_child(self.views[4].previous_view)
+                (self.curr_view == self.views[4] or self.curr_view == self.views[5])):
+            if self.toolbar._state == ToolbarState.MAIN:
+                # We should get back to the view before the search
+                self._stack.set_visible_child(self.views[4].previous_view)
+            elif (self.views[4].previous_view == self.views[0] and
+                 self.curr_view.get_visible_child() != self.curr_view._albumWidget):
+                self._stack.set_visible_child(self.views[0])
+
             if self.toolbar._selectionMode:
                 self.toolbar.set_selection_mode(False)
 
